@@ -41,7 +41,7 @@
 #include <exchange-mapi-connection.h>
 #include <exchange-mapi-utils.h>
 
-#define d(x) x
+#define d(x)
 
 G_DEFINE_TYPE (ExchangeMAPIAccountListener, exchange_mapi_account_listener, G_TYPE_OBJECT)
 
@@ -314,8 +314,7 @@ add_cal_esource (EAccount *account, GSList *folders, ExchangeMAPIFolderType fold
 			ESource *source = temp_list->data;
 
 			if (source && E_IS_SOURCE (source)) {
-				if (!e_source_get_property (source, "public") ||
-				    strcmp (e_source_get_property (source, "public"), "yes") != 0)
+				if (strcmp (e_source_get_property (source, "public"), "yes") != 0)
 					e_source_group_remove_source (group, source);
 			}
 		}
@@ -715,8 +714,7 @@ add_addressbook_sources (EAccount *account, GSList *folders, mapi_id_t trash_fid
 			ESource *source = temp_list->data;
 
 			if (source && E_IS_SOURCE (source)) {
-				if (!e_source_get_property (source, "public") ||
-				    strcmp (e_source_get_property (source, "public"), "yes") != 0)
+				if (strcmp(e_source_get_property(source, "public"), "yes") != 0)
 					e_source_group_remove_source (group, source);
 			}
 		}
